@@ -299,7 +299,7 @@ class LoadMaster(HttpClient):
 
     def backup(self):
         response = self._get('/backup')
-        if ApiXmlHelper.is_successful(response):
-            return ApiXmlHelper.parse_to_dict(response)
-        else:
-            raise KempTechApiException(ApiXmlHelper.get_error_msg(response))
+        file_name = "{}.backup".format(self.ip_address)
+        with open(file_name, "wb") as backup_file:
+            backup_file.write(response)
+            return file_name
